tlslite.utils.tackwrapper

Package tlslite :: Package utils :: Module tackwrapper |
[hide private]
[frames] | no frames]

# Source Code for Module tlslite.utils.tackwrapper

     1  # Author: Trevor Perrin
     2  # See the LICENSE file for legal information regarding use of this file.
     3
     4  try:
     5      from tack.structures.Tack import Tack
     6      from tack.structures.TackExtension import TackExtension
     7      from tack.tls.TlsCertificate import TlsCertificate
     8
     9      tackpyLoaded = True
    10  except ImportError:
    11      tackpyLoaded = False
    12